%feature("docstring") OT::AbsoluteExponential
"Absolute exponential covariance function.

Available constructors:
    AbsoluteExponential(*spatialDim=1*)

    AbsoluteExponential(*scale*)

    AbsoluteExponential(*scale, amplitude*)

Parameters
----------
spatialDim : int
    Spatial dimension :math:`n`.
    When not fulfilled, the spatial dimension is equal to the  size of the parameter :math:`\\\\vect{\\\\theta}`.
    By default, equal to 1.
scale : sequence of floats
    Scale coefficient :math:`\\\\vect{\\\\theta}\\\\in \\\\Rset^n`.
    The size of :math:`\\\\vect{\\\\theta}` is the spatial dimension.
amplitude : sequence of positive floats
    Amplitude  :math:`\\\\vect{\\\\sigma}\\\\in \\\\Rset^d`.
    Must be of size equal to 1.
    By default, equal to :math:`[1]`.


Notes
-----
The *absolute exponential* function is a stationary covariance function whith dimension :math:`d=1`.

We consider the scalar stochastic process :math:`X: \\\\Omega \\\\times\\\\cD \\\\mapsto \\\\Rset`, where :math:`\\\\omega \\\\in \\\\Omega` is an event, :math:`\\\\cD` is a domain of :math:`\\\\Rset^n`.

The  *absolute exponential* function is defined by:

.. math::

    C(\\\\vect{s}, \\\\vect{t}) = \\\\sigma^2 e^{- \\\\left\\\\|\\\\dfrac{\\\\vect{s}-\\\\vect{t}}{\\\\vect{\\\\theta}}\\\\right\\\\|_{1}}, \\\\quad \\\\forall (\\\\vect{s}, \\\\vect{t}) \\\\in \\\\cD

The correlation function :math:`\\\\rho` writes:

.. math::

    \\\\rho(\\\\vect{s}, \\\\vect{t}) = e^{- \\\\left\\\\| \\\\vect{s}- \\\\vect{t} \\\\right\\\\|_{1}}, \\\\quad \\\\forall (\\\\vect{s}, \\\\vect{t}) \\\\in \\\\cD


See Also
--------
CovarianceModel

Examples
--------
Create a standard absolute exponential covariance function:

>>> import openturns as ot
>>> covModel = ot.AbsoluteExponential(2)
>>> t = [0.1, 0.3]
>>> s = [0.2, 0.4]
>>> print(covModel(s, t))
[[ 0.818731 ]]
>>> tau = [0.1, 0.3]
>>> print(covModel(tau))
[[ 0.67032 ]]

Create an absolute exponential covariance function specifying only the scale vector (amplitude is fixed to 1):

>>> covModel2 = ot.AbsoluteExponential([1.5, 2.5])
>>> covModel2bis = ot.AbsoluteExponential([1.5]*3)

Create an absolute exponential covariance function specifying the scale vector and the amplitude :

>>> covModel3 = ot.AbsoluteExponential([1.5, 2.5], [3.5])"
