%feature("docstring") OT::BetaMuSigma
"Beta distribution parameters.

Available constructors:
    BetaMuSigma(*mu=0.5, sigma=* :math:`1/(2\\\\sqrt{5})` *, a=0.0, b=1.0*)

Parameters
----------
mu : float
    Mean.
sigma : float
    Standard deviation :math:`\\\\sigma > 0`.
a : float
    Lower bound.
b : float, :math:`b > a`
    Upper bound.

Notes
-----
The native parameters are defined as follows:

.. math::

    t &= \\\\frac{(b - \\\\mu) (\\\\mu - a)}{\\\\sigma^2} - 1.0 \\\\\\\\
    r &= \\\\frac{\\\\mu - a}{b - a} t

See also
--------
Beta

Examples
--------
Create the parameters of the Beta distribution:

>>> import openturns as ot
>>> parameters = ot.BetaMuSigma(0.2, 0.6, -1, 2)

Convert parameters into the native parameters:

>>> print(parameters.evaluate())
[2,5,-1,2]

The gradient of the transformation of the native parameters into the new
parameters:

>>> print(parameters.gradient())
[[   2.33333    1.66667    0          0        ]
 [  -8        -20          0          0        ]
 [  -3         -5          1          0        ]
 [   0.666667   3.33333    0          1        ]]"
