%feature("docstring") OT::BootstrapExperiment
"Bootstrap experiment.

Available constructors:
    BootstrapExperiment(*sample*)

Parameters
----------
sample : 2-d sequence of float
    Points to defined a :class:`~openturns.UserDefined` distribution
    :math:`\\\\mu`.

Notes
-----
BootstrapExperiment is a random weighted design of experiments.
To call the BootstrapExperiment constructor is equivalent to call the
:class:`~openturns.WeightedExperiment` constructor as follows:
*WeightedExperiment(UserDefined(sample), sample.getSize())*.

See also
--------
WeightedExperiment

Examples
--------
>>> import openturns as ot
>>> ot.RandomGenerator.SetSeed(0)
>>> sample = [[i,i+1] for i in range(5)]
>>> myPlane = ot.BootstrapExperiment(sample)
>>> print(myPlane.generate())
    [ v0 v1 ]
0 : [ 4  5  ]
1 : [ 1  2  ]
2 : [ 1  2  ]
3 : [ 1  2  ]
4 : [ 2  3  ]
>>> print(myPlane.getDistribution())
UserDefined({x = [0,1], p = 0.2}, {x = [1,2], p = 0.2}, {x = [2,3], p = 0.2}, {x = [3,4], p = 0.2}, {x = [4,5], p = 0.2})"
