%feature("docstring") OT::GumbelAB
"Gumbel distribution parameters.

Available constructors:
    GumbelAB(*a=0.0, b=1.0*)

Parameters
----------
a : float
    Location parameter.
b : float
    Scale parameter :math:`b > 0`.

Notes
-----
The native parameters are defined as follows:

.. math::

    \\\\alpha &= \\\\frac{1}{b} \\\\\\\\
    \\\\beta &= a

See also
--------
Gumbel

Examples
--------
Create the parameters of the Gumbel distribution:

>>> import openturns as ot
>>> parameters = ot.GumbelAB(-0.5, 0.5)

Convert parameters into the native parameters:

>>> print(parameters.evaluate())
[2,-0.5]

The gradient of the transformation of the native parameters into the new
parameters:

>>> print(parameters.gradient())
[[  0  1 ]
 [ -4  0 ]]"
