%feature("docstring") OT::GumbelMuSigma
"Gumbel distribution parameters.

Available constructors:
    GumbelMuSigma(*mu=* :math:`\\\\gamma` *, sigma=* :math:`\\\\pi/\\\\sqrt{6}`)

Parameters
----------
mu : float
    Mean.
sigma : float
    Standard deviation :math:`\\\\sigma > 0`.

Notes
-----
The native parameters are defined as follows:

.. math::

    \\\\alpha &= \\\\frac{\\\\pi}{\\\\sigma \\\\sqrt{6}} \\\\\\\\
    \\\\beta &= \\\\mu - \\\\frac{\\\\gamma \\\\sigma \\\\sqrt{6}}{\\\\pi}

where :math:`\\\\gamma` is the Euler-Mascheroni constant.

See also
--------
Gumbel

Examples
--------
Create the parameters of the Gumbel distribution:

>>> import openturns as ot
>>> parameters = ot.GumbelMuSigma(1.5, 1.3)

Convert parameters into the native parameters:

>>> print(parameters.evaluate())
[0.986577,0.914931]

The gradient of the transformation of the native parameters into the new
parameters:

>>> print(parameters.gradient())
[[  0         1        ]
 [ -0.758905 -0.450053 ]]"
