%feature("docstring") OT::InverseNormal
"Inverse normal distribution.

Available constructors:
    InverseNormal(*lambda=1.0, mu=1.0*)

Parameters
----------
lambda : float, :math:`\\\\lambda > 0`
    Scale parameter :math:`\\\\lambda`.
mu : float, :math:`\\\\mu > 0`
    Location (mean) parameter :math:`\\\\mu`.

Notes
-----
Its probability density function is defined as:

.. math::

    f_X(x) = \\\\sqrt{\\\\frac{\\\\lambda}{2 \\\\pi x^3}}
             \\\\exp\\\\left(\\\\frac{- \\\\lambda (x - \\\\mu)^2}{2 \\\\mu^2 x}\\\\right),
             \\\\quad x \\\\in [0; +\\\\infty[

with :math:`\\\\lambda, \\\\mu > 0`.

Its first moments are:

.. math::
    :nowrap:

    \\\\begin{eqnarray*}
        \\\\Expect{X} & = & \\\\mu \\\\\\\\
        \\\\Var{X} & = & \\\\frac{\\\\mu^3}{\\\\lambda}
    \\\\end{eqnarray*}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> distribution = ot.InverseNormal(1.0, 1.0)

Draw a sample:

>>> sample = distribution.getSample(5)"

// ---------------------------------------------------------------------

%feature("docstring") OT::InverseNormal::getLambda
"Accessor to the distribution's scale parameter.

Returns
-------
lambda : float
    Scale parameter :math:`\\\\lambda`."

// ---------------------------------------------------------------------

%feature("docstring") OT::InverseNormal::getMu
"Accessor to the distribution's location (mean) parameter.

Returns
-------
mu : float
    Location (mean) parameter :math:`\\\\mu`."

// ---------------------------------------------------------------------

%feature("docstring") OT::InverseNormal::setLambdaMu
"Accessor to the distribution's parameters.

Parameters
----------
lambda : float, :math:`\\\\lambda > 0`
    Scale parameter :math:`\\\\lambda`.
mu : float, :math:`\\\\mu > 0`
    Location (mean) parameter :math:`\\\\mu`."
