%feature("docstring") OT::LinearModel
"The linear model class is created through the method build of a LinearModelFactory.

See Also
--------
LinearModelFactory
"

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModel::getConfidenceIntervals
"Accessor to the confidence intervals.

Returns
-------
confInterval : :class:`~openturns.Interval`
    The confidence intervals of the linear model coefficients,
    corresponding to the level precised when the LinearModel class has been
    created through the method *build*."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModel::getPValues
"Accessor to the p-values.

Returns
-------
pvalues : collection of :class:`~openturns.Scalar`
    The collection of the p-values of the linear model coefficients."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModel::getPredicted
"Accessor to the evaluation function of linear model.

Parameters
----------
sampleX : 2-d sequence of float
    The input sample to be evaluated by the linear model.

Returns
-------
Y : :class:`~openturns.Sample`
    The response :math:`Y` evaluated through the linear model on the sample
    *sampleX*."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModel::getRegression
"Accessor to the regression coefficients.

Returns
-------
coef : :class:`~openturns.Point`
    The coefficients of the linear model: :math:`(a_0, a_1, \\\\ldots, a_n)`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModel::getResidual
"Accessor to the residuals.

Parameters
----------
Xsample: 2-d sequence of float
    The input sample on which the linear model has been built.
Ysample: 2-d sequence of float
    The 1d output sample on which the linear model has been built.

Returns
-------
residual : :class:`~openturns.Sample`
    The residuals computed on each point."
