%feature("docstring") OT::Pairs
"Pairs.

Available constructors:
    Pairs(*data, title=' '*)

    Pairs(*data, title, labels, color, pointStyle*)

Parameters
----------
data : 2-d sequence of float of dimension :math:`n`
    Points from which 2D clouds are built.
title : str
    Title of the Pairs.
labels : sequence of str of dimension :math:`n`
    Names of each component of the sample.
color : str
    Color of the points. If not specified, by default it is 'blue'.
pointStyle : str
    Style of the points. If not specified, by default it is 'plus'.

Examples
--------
>>> import openturns as ot
>>> R = ot.CorrelationMatrix(3)
>>> R[1, 0] = -0.4
>>> R[2, 1] = -0.4
>>> distribution = ot.Normal([0.0] * 3, [5.0] * 3, R)
>>> sample = distribution.getSample(10)
>>> # Create an empty graph
>>> myGraph = ot.Graph('Pairs', ' ', ' ', True, '')
>>> # Create the Pairs
>>> myPairs = ot.Pairs(sample, 'Pairs example', sample.getDescription(), 'blue', 'bullet')
>>> myGraph.add(myPairs)"

// ---------------------------------------------------------------------

%feature("docstring") OT::Pairs::buildDefaultLabels
"Build default labels by taking the column number of *data*."

// ---------------------------------------------------------------------

%feature("docstring") OT::Pairs::getTitle
"Get the title of the Pairs.

Returns
-------
title : str
    Title of the Pairs."

// ---------------------------------------------------------------------

%feature("docstring") OT::Pairs::setTitle
"Set the title of the Pairs.

Parameters
----------
title : str
    Title of the Pairs."
