%feature("docstring") OT::Poisson
"Poisson distribution.

Available constructors:
    Poisson(*lambda=1.0*)

Parameters
----------
lambda : float, :math:`\\\\lambda > 0`
    Mean and variance value.

Notes
-----
Its probability density function is defined as:

.. math::

    \\\\Prob{X = k} = \\\\frac{\\\\lambda^k}{k!}\\\\;e^{-\\\\lambda}, \\\\,  k \\\\in \\\\Nset

Its first moments are:

.. math::
    :nowrap:

    \\\\begin{eqnarray*}
        \\\\Expect{X} & = & \\\\lambda \\\\\\\\
        \\\\Var{X} & = & sqrt{\\\\lambda}
    \\\\end{eqnarray*}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> distribution = ot.Poisson(10.0)

Draw a sample:

>>> sample = distribution.getSample(5)"

// ---------------------------------------------------------------------

%feature("docstring") OT::Poisson::getLambda
"Accessor to the distribution's mean and variance value.

Returns
-------
lambda : float
    Distribution's mean and variance value."

// ---------------------------------------------------------------------

%feature("docstring") OT::Poisson::setLambda
"Accessor to the distribution's mean and variance value.

Parameters
----------
lambda : float
    Distribution's mean and variance value."
