%feature("docstring") OT::ResourceMap
"The ResourceMap allows to manage constants that are associated to key strings.

Find below the ResourceMap's content:

.. execforresourcemap::

Examples
--------
Get some keys:

>>> import openturns as ot
>>> for key in ot.ResourceMap.GetKeys()[:4]:
...     print(key)
ARMA-MeanEpsilon
ARMALikelihoodFactory-DefaultMaxFun
ARMALikelihoodFactory-DefaultRhoBeg
ARMALikelihoodFactory-DefaultRhoEnd"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::Get
"Access a parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.

Returns
-------
value : str
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.Get('DiscreteDistribution-SupportEpsilon')
'1.0e-14'"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::Set
"Access a parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.
value : str
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.Set('DiscreteDistribution-SupportEpsilon', '1.0e-14')"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsBool
"Access a boolean parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.

Returns
-------
value : bool
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsBool('MaximumEntropyOrderStatisticsDistribution-CheckMarginals')
True"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsBool
"Access a boolean parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.
value : bool
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsBool('MaximumEntropyOrderStatisticsDistribution-CheckMarginals', True)"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsScalar
"Access a floating-point parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.
value : float
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsScalar('SQP-DefaultTau', 0.5)"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsScalar
"Access a floating-point parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.

Returns
-------
value : float
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsScalar('SQP-DefaultTau')
0.5"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsUnsignedInteger
"Access an integer parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.
value : int
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsUnsignedInteger('MCMC-DefaultBurnIn', 0)"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsUnsignedInteger
"Access an integer parameter.

Parameters
----------
key : str
    An identifier associated to the parameter.

Returns
-------
value : int
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsUnsignedInteger('MCMC-DefaultBurnIn')
0..."

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetSize
"Get the size of the ResourceMap.

Returns
-------
size : positive int
    The number of constants defined in the ResourceMap."

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetKeys
"Get the keys of the ResourceMap.

Returns
-------
keys : tuple of str
    The list of identifiers."

